function M = M_cont_original(Pvid)

% Calculates the mixing index of an image sequence using the original
% contact method. The normalization uses the maximum and minimum number of
% contacts in the image sequence.

% Theodoros-Nestor Papapetrou
% Last edited: 06 Oct 2020

%% Input

% Pvid: uint8 H x W x F matrix with values corresponding to colors:
% 1: red, 2: white, 0: background (black)
% H, W, F: height, width, frames
% Each page of Pvid, Pvid(:,:,ii) represents an image of the rotating drum
% at frame ii with red and white particles

%% Output

% M: F x 1 double array, the value of the mixing index for each frame

%% Calculations

[~,~,F] = size(Pvid);
C = zeros(F,1); % number of contacts of each image

for ii = 1:F
    P = Pvid(:,:,ii);
    C(ii) = find_noOfContacts(P,'both');
end

C_min = min(C);
C_max = max(C);
M = (C - C_min)./(C_max - C_min); % Eq. 3