function [Mmin,Mmax,M] = M_variance_minmax(P,winSize)

% Calculates the minimum and the maximum mixing index of an image, for a
% given window size and across all posible grid positions, using the
% variance method.

% Theodoros-Nestor Papapetrou
% Last edited: 09 Oct 2020

%% Input

% P: uint8 H x W matrix with values corresponding to colors:
% 1: red, 2: white, 0: background (black)
% P represents an image of the rotating drum with red and white particles

% winSize: integer array with one or two elements
% It defines the size of the rectangle-shaped window as [noOfRows noOfCols]
% Each element should be less than the corresponding size of P
% If winSize has one element, square-shaped windows are used

%% Output

% Mmin: the minimum value of the mixing index, double scalar between 0 and
% 1

% Mmax: the minimum value of the mixing index, double scalar between 0 and
% 1

% M: the values of the mixing index for all possible grid positions, double
% matrix of size(winSize), values between 0 and 1

%% Initialization

[winH,winW] = size(winSize);
M = zeros(size(winSize)); % the index values for each vertex

%% Calculations

for ii = 1:winH
    for jj = 1:winW
        
        vertex = [ii jj];
        M(ii,jj) = M_variance(P,winSize,vertex);
        
    end
end

%% Minimum and maximum values

Mmin = min(M,[],'all');
Mmax = max(M,[],'all');
