function Pvid = RGBartif2P(RGBartif)

% Converts an RGB video that only contains red, white and black pixels,
% into the corresponding Pvid video. Such an RGB video may consist of
% artificial images, or of images that came from a Pvid in the first place.
% It is the inverse function of Pvid2RGB.

% Theodoros-Nestor Papapetrou
% Last edited: 08 Oct 2020

%% Input

% RGBartif: H x W x 3 x F uint8 array, that only contains red (255,0,0),
% white (255,255,255) and black (0,0,0) pixels

%% Output

% Pvid: uint8 H x W x F matrix with values corresponding to colors:
% 1: red, 2: white, 0: background (black)

%% Calculations

%% Initialization

RGBsize = size(RGBartif);
H = RGBsize(1);
W = RGBsize(2);

% Check if Pvid corresponds to a video (F > 1) or a single image (F = 1)
if numel(RGBsize) == 3 % single image
    F = 1;
else % video
    F = RGBsize(4);
end

Pvid = zeros([H,W,F],'uint8');

%% Conversion of each frame

for fr = 1:F
    
    RGB = RGBartif(:,:,:,fr);
    P = zeros([H,W],'uint8');
    
    R = RGB(:,:,1); % red channel
    G = RGB(:,:,2); % green channel
    
    P(G == 255) = 2; % white pixels
    P(R > G ) = 1; % red pixels
    
    Pvid(:,:,fr) = P;
    
end